use strict;
use warnings;
package Textoola;
$Textoola::VERSION = '0.003';
# ABSTRACT: Statistical text and string analysis tools

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Textoola - Statistical text and string analysis tools

=head1 VERSION

version 0.003

=head1 AUTHOR

Sascha Dibbern <sacha@dibbern.info>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Sascha Dibbern.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
